summaryrefslogtreecommitdiffstats
path: root/libkdcraw
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:26:14 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:26:14 -0600
commitd215ae5a1d92365ee442171006da58078942e87e (patch)
treed42741b2ded06e3f95ad441dbe7e292e9c74d257 /libkdcraw
parent7abaaf2bfdfde358ceeac5c4bdf087ba005e25d9 (diff)
downloadlibkdcraw-d215ae5a1d92365ee442171006da58078942e87e.tar.gz
libkdcraw-d215ae5a1d92365ee442171006da58078942e87e.zip
Rename additional global TQt functions
Diffstat (limited to 'libkdcraw')
-rw-r--r--libkdcraw/libkdcraw/dcrawbinary.cpp2
-rw-r--r--libkdcraw/libkdcraw/kdcraw.cpp52
-rw-r--r--libkdcraw/libkdcraw/kdcrawprivate.cpp6
-rw-r--r--libkdcraw/test/raw2png.cpp2
4 files changed, 31 insertions, 31 deletions
diff --git a/libkdcraw/libkdcraw/dcrawbinary.cpp b/libkdcraw/libkdcraw/dcrawbinary.cpp
index 8efafb6..08a80e9 100644
--- a/libkdcraw/libkdcraw/dcrawbinary.cpp
+++ b/libkdcraw/libkdcraw/dcrawbinary.cpp
@@ -107,7 +107,7 @@ void DcrawBinary::slotReadStdoutFromDcraw(KProcess*, char* buffer, int buflen)
if (firstLine.startsWith(dcrawHeader))
{
d->version = firstLine.remove(0, dcrawHeader.length());
- qDebug("Found dcraw version: %s", version().ascii());
+ tqDebug("Found dcraw version: %s", version().ascii());
}
}
diff --git a/libkdcraw/test/raw2png.cpp b/libkdcraw/test/raw2png.cpp
index a678c98..4828264 100644
--- a/libkdcraw/test/raw2png.cpp
+++ b/libkdcraw/test/raw2png.cpp
@@ -32,7 +32,7 @@
#if KDE_IS_VERSION(4,0,0)
#include "tqdebug.h"
-#define PRINT_DEBUG qDebug()
+#define PRINT_DEBUG tqDebug()
#define ENDL
#else
#include "kdebug.h"
diff --git a/libkdcraw/libkdcraw/kdcraw.cpp b/libkdcraw/libkdcraw/kdcraw.cpp
index 39948cd..c70b315 100644
--- a/libkdcraw/libkdcraw/kdcraw.cpp
+++ b/libkdcraw/libkdcraw/kdcraw.cpp
@@ -11,7 +11,7 @@
* Copyright (C) 2007-2008 by Guillaume Castagnino <casta at xwing dot info>
*
* NOTE: Do not use kdDebug() in this implementation because
* it will be multithreaded. Use qDebug() instead.
* See B.K.O #133026 for details.
*
* This program is free software; you can redistribute it
@@ -85,16 +85,16 @@ bool KDcraw::loadEmbeddedPreview(TQImage& image, const TQString& path)
if ( loadEmbeddedPreview(imgData, path) )
{
- qDebug("Preview data size: %i", imgData.size());
+ tqDebug("Preview data size: %i", imgData.size());
if (image.loadFromData( imgData ))
{
- qDebug("Using embedded RAW preview extraction");
+ tqDebug("Using embedded RAW preview extraction");
return true;
}
}
- qDebug("Failed to load embedded RAW preview");
+ tqDebug("Failed to load embedded RAW preview");
return false;
}
@@ -112,7 +112,7 @@ bool KDcraw::loadEmbeddedPreview(TQByteArray& imgData, const TQString& path)
int ret = raw.open_file((const char*)(TQFile::encodeName(path)));
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -121,7 +121,7 @@ bool KDcraw::loadEmbeddedPreview(TQByteArray& imgData, const TQString& path)
if (ret != LIBRAW_SUCCESS)
{
raw.recycle();
- qDebug("LibRaw: failed to run unpack_thumb: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run unpack_thumb: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -129,7 +129,7 @@ bool KDcraw::loadEmbeddedPreview(TQByteArray& imgData, const TQString& path)
libraw_processed_image_t *thumb = raw.dcraw_make_mem_thumb(&ret);
if(!thumb)
{
- qDebug("LibRaw: failed to run dcraw_make_mem_thumb: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run dcraw_make_mem_thumb: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -149,7 +149,7 @@ bool KDcraw::loadEmbeddedPreview(TQByteArray& imgData, const TQString& path)
if ( imgData.isEmpty() )
{
- qDebug("Failed to load JPEG thumb from LibRaw!");
+ tqDebug("Failed to load JPEG thumb from LibRaw!");
return false;
}
@@ -165,7 +165,7 @@ bool KDcraw::loadHalfPreview(TQImage& image, const TQString& path)
if (!fileInfo.exists() || ext.isEmpty() || !rawFilesExt.upper().contains(ext))
return false;
- qDebug("Try to use reduced RAW picture extraction");
+ tqDebug("Try to use reduced RAW picture extraction");
LibRaw raw;
raw.imgdata.params.use_auto_wb = 1; // Use automatic white balance.
@@ -178,7 +178,7 @@ bool KDcraw::loadHalfPreview(TQImage& image, const TQString& path)
int ret = raw.open_file((const char*)(TQFile::encodeName(path)));
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -186,7 +186,7 @@ bool KDcraw::loadHalfPreview(TQImage& image, const TQString& path)
ret = raw.unpack();
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run unpack: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run unpack: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -194,7 +194,7 @@ bool KDcraw::loadHalfPreview(TQImage& image, const TQString& path)
ret = raw.dcraw_process();
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run dcraw_process: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run dcraw_process: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -202,7 +202,7 @@ bool KDcraw::loadHalfPreview(TQImage& image, const TQString& path)
libraw_processed_image_t *halfImg = raw.dcraw_make_mem_image(&ret);
if(!halfImg)
{
- qDebug("LibRaw: failed to run dcraw_make_mem_image: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run dcraw_make_mem_image: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -214,11 +214,11 @@ bool KDcraw::loadHalfPreview(TQImage& image, const TQString& path)
if (!image.loadFromData(imgData))
{
- qDebug("Failed to load PPM data from LibRaw!");
+ tqDebug("Failed to load PPM data from LibRaw!");
return false;
}
- qDebug("Using reduced RAW picture extraction");
+ tqDebug("Using reduced RAW picture extraction");
return true;
}
@@ -237,7 +237,7 @@ bool KDcraw::rawFileIdentify(DcrawInfoContainer& identify, const TQString& path)
int ret = raw.open_file((const char*)(TQFile::encodeName(path)));
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -245,7 +245,7 @@ bool KDcraw::rawFileIdentify(DcrawInfoContainer& identify, const TQString& path)
ret = raw.adjust_sizes_info_only();
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run adjust_sizes_info_only: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run adjust_sizes_info_only: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -279,7 +279,7 @@ bool KDcraw::extractRAWData(const TQString& filePath, TQByteArray &rawData, Dcra
int ret = raw.open_file((const char*)(TQFile::encodeName(filePath)));
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -297,7 +297,7 @@ bool KDcraw::extractRAWData(const TQString& filePath, TQByteArray &rawData, Dcra
ret = raw.unpack();
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run unpack: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run unpack: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -548,7 +548,7 @@ bool KDcraw::loadFromDcraw(const TQString& filePath, TQByteArray &imageData,
RGB[0] = 1.0 / RGB[0];
RGB[1] = 1.0 / RGB[1];
RGB[2] = 1.0 / RGB[2];
- qDebug("Warning: cannot get daylight multipliers");
+ tqDebug("Warning: cannot get daylight multipliers");
}
// (-r) set Raw Color Balance Multipliers.
@@ -644,12 +644,12 @@ bool KDcraw::loadFromDcraw(const TQString& filePath, TQByteArray &imageData,
d->setProgress(0.1);
args.append(filePath);
- qDebug("LibRaw: dcraw emulation: %s", args.join(", ").ascii());
+ tqDebug("LibRaw: dcraw emulation: %s", args.join(", ").ascii());
int ret = raw.open_file((const char*)(TQFile::encodeName(filePath)));
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run open_file: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -664,7 +664,7 @@ bool KDcraw::loadFromDcraw(const TQString& filePath, TQByteArray &imageData,
ret = raw.unpack();
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run unpack: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run unpack: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -679,7 +679,7 @@ bool KDcraw::loadFromDcraw(const TQString& filePath, TQByteArray &imageData,
ret = raw.dcraw_process();
if (ret != LIBRAW_SUCCESS)
{
- qDebug("LibRaw: failed to run dcraw_process: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run dcraw_process: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -694,7 +694,7 @@ bool KDcraw::loadFromDcraw(const TQString& filePath, TQByteArray &imageData,
libraw_processed_image_t *img = raw.dcraw_make_mem_image(&ret);
if(!img)
{
- qDebug("LibRaw: failed to run dcraw_make_mem_image: %s", libraw_strerror(ret));
+ tqDebug("LibRaw: failed to run dcraw_make_mem_image: %s", libraw_strerror(ret));
raw.recycle();
return false;
}
@@ -720,7 +720,7 @@ bool KDcraw::loadFromDcraw(const TQString& filePath, TQByteArray &imageData,
return false;
d->setProgress(0.4);
- qDebug("LibRaw: data info: width %i height %i rgbmax %i", width, height, rgbmax);
+ tqDebug("LibRaw: data info: width %i height %i rgbmax %i", width, height, rgbmax);
return true;
}
@@ -11,7 +11,7 @@
*
* NOTE: Do not use kdDebug() in this implementation because
- * it will be multithreaded. Use qDebug() instead.
+ * it will be multithreaded. Use tqDebug() instead.
* See B.K.O #133026 for details.
*
diff --git a/libkdcraw/libkdcraw/kdcrawprivate.cpp b/libkdcraw/libkdcraw/kdcrawprivate.cpp
index 356ba6d..df95fd0 100644
--- a/libkdcraw/libkdcraw/kdcrawprivate.cpp
+++ b/libkdcraw/libkdcraw/kdcrawprivate.cpp
@@ -9,7 +9,7 @@
* Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
*
* NOTE: Do not use kdDebug() in this implementation because
* it will be multithreaded. Use qDebug() instead.
* See B.K.O #133026 for details.
*
* This program is free software; you can redistribute it
@@ -78,7 +78,7 @@ void KDcrawPriv::createPPMHeader(TQByteArray& imgData, libraw_processed_image_t
int KDcrawPriv::progressCallback(enum LibRaw_progress p, int iteration, int expected)
{
- qDebug("LibRaw progress: %s pass %i of %i", libraw_strprogress(p), iteration, expected);
+ tqDebug("LibRaw progress: %s pass %i of %i", libraw_strprogress(p), iteration, expected);
// post a little change in progress indicator to show raw processor activity.
setProgress(progressValue()+0.01);
@@ -86,7 +86,7 @@ int KDcrawPriv::progressCallback(enum LibRaw_progress p, int iteration, int expe
// Clean processing termination by user...
if(m_parent->checkToCancelWaitingData())
{
- qDebug("LibRaw process terminaison invoked...");
+ tqDebug("LibRaw process terminaison invoked...");
m_parent->m_cancel = true;
return 1;
}
@@ -9,7 +9,7 @@
*
* NOTE: Do not use kdDebug() in this implementation because
- * it will be multithreaded. Use qDebug() instead.
+ * it will be multithreaded. Use tqDebug() instead.
* See B.K.O #133026 for details.
*